==> haskell-th-utilities-0.2.1.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.1.0
id: th-utilities-0.2.1.0-IUvYvv0CMfF9zag59uFXuJ
key: th-utilities-0.2.1.0-IUvYvv0CMfF9zag59uFXuJ
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <mgsloan@gmail.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: 42fc9e0412c69e7add8ae9c1f98c33dc
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/th-utilities-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/th-utilities-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/th-utilities-0.2.1.0
hs-libraries: HSth-utilities-0.2.1.0-IUvYvv0CMfF9zag59uFXuJ
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 th-orphans-0.13.6-9VHWlm0yrfWBrLFmsqxZpS
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.1.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-utilities
version: 0.2.1.0
id: th-utilities-0.2.1.0-1bHY4sDuSi1KCsRXknN9RC
key: th-utilities-0.2.1.0-1bHY4sDuSi1KCsRXknN9RC
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <mgsloan@gmail.com>
homepage: https://github.com/fpco/th-utilities#readme
synopsis: Collection of useful functions for use with Template Haskell
category: Template Haskell
abi: a3e17d28b59101734bf4bdcae38dc796
exposed: True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.ReifySimple TH.RelativePaths
    TH.Utilities
hidden-modules: TH.Derive.Internal
import-dirs: /usr/lib/ghc-8.6.4/site-local/th-utilities-0.2.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/th-utilities-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/th-utilities-0.2.1.0
hs-libraries: HSth-utilities-0.2.1.0-1bHY4sDuSi1KCsRXknN9RC
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    text-1.2.3.1 th-orphans-0.13.7-9HxNkXjP00VE8cbS6uSzK5
haddock-interfaces: /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock
haddock-html: /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
